i64x8

Struct i64x8 

pub struct i64x8 { /* private fields */ }

Implementations

Source

impl i64x8

pub const ONE: i64x8

pub const ZERO: i64x8

pub const MAX: i64x8

pub const MIN: i64x8

pub const LANES: u16 = 8

The number of lanes in this SIMD vector.

pub const BITS: u16 = 512

The size of this SIMD vector in bits.

Source

impl i64x8

pub const fn new(array: [i64; 8]) -> Self

pub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Output
where Self: CmpEq<Rhs>,

Test if each element is equal to the corresponding element in other.

pub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Output
where Self: CmpNe<Rhs>,

Test if each element is not equal to the corresponding element in other.

pub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Output
where Self: CmpLt<Rhs>,

Test if each element is less than the corresponding element in other.

pub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Output
where Self: CmpGt<Rhs>,

Test if each element is greater than the corresponding element in other.

pub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Output
where Self: CmpLe<Rhs>,

Test if each element is less than or equal to the corresponding element in other.

pub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Output
where Self: CmpGe<Rhs>,

Test if each element is greater than or equal to the corresponding element in other.

pub fn blend(self, t: Self, f: Self) -> Self

pub fn is_positive(self) -> Self

Returns true for each positive element and false if it is zero or negative.

pub fn is_negative(self) -> Self

Returns true for each negative element and false if it is zero or positive.

pub fn reduce_add(self) -> i64

pub fn reduce_max(self) -> i64

pub fn reduce_min(self) -> i64

pub fn abs(self) -> Self

pub fn unsigned_abs(self) -> u64x8

pub fn signum(self) -> Self

Returns numbers representing the sign of each element.

  • 0 if the number is zero
  • 1 if the number is positive
  • -1 if the number is negative
pub fn round_float(self) -> f64x8

pub fn to_bitmask(self) -> u32

returns the bit mask for each high bit set in the vector with the lowest lane being the lowest bit

pub fn any(self) -> bool

true if any high bits are set for any value in the vector

pub fn all(self) -> bool

true if all high bits are set for every value in the vector

pub fn none(self) -> bool

true if no high bits are set for any values of the vector

pub fn transpose(data: [i64x8; 8]) -> [i64x8; 8]

Transpose matrix of 8x8 i64 matrix. Currently not accelerated.

pub fn to_array(self) -> [i64; 8]

pub fn as_array(&self) -> &[i64; 8]

pub fn as_mut_array(&mut self) -> &mut [i64; 8]

pub fn min(self, rhs: Self) -> Self

pub fn max(self, rhs: Self) -> Self

pub fn clamp(self, min: Self, max: Self) -> Self

Restrict each element to a certain interval.

If min > max, the result is unspeficied. Consider manually checking for that case.

pub fn saturating_add(self, rhs: Self) -> Self

pub fn saturating_sub(self, rhs: Self) -> Self

pub fn saturating_mul(self, rhs: Self) -> Self

Lanewise saturating multiply.

pub fn saturating_div(self, rhs: Self) -> Self

Lanewise saturating divide.

Note that because division has no hardware support, this operation is very slow and should be avoided if possible.

Source

impl i64x8

pub const fn splat(elem: i64) -> i64x8