i8x16

Struct i8x16 

pub struct i8x16 { /* private fields */ }

Implementations

Source

impl i8x16

pub const ONE: i8x16

pub const ZERO: i8x16

pub const MAX: i8x16

pub const MIN: i8x16

pub const LANES: u16 = 16

The number of lanes in this SIMD vector.

pub const BITS: u16 = 128

The size of this SIMD vector in bits.

Source

impl i8x16

pub const fn new(array: [i8; 16]) -> Self

pub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Output
where Self: CmpEq<Rhs>,

Test if each element is equal to the corresponding element in other.

pub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Output
where Self: CmpNe<Rhs>,

Test if each element is not equal to the corresponding element in other.

pub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Output
where Self: CmpLt<Rhs>,

Test if each element is less than the corresponding element in other.

pub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Output
where Self: CmpGt<Rhs>,

Test if each element is greater than the corresponding element in other.

pub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Output
where Self: CmpLe<Rhs>,

Test if each element is less than or equal to the corresponding element in other.

pub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Output
where Self: CmpGe<Rhs>,

Test if each element is greater than or equal to the corresponding element in other.

pub fn from_i16x16_saturate(v: i16x16) -> i8x16

converts i16 to i8, saturating values that are too large

pub fn from_i16x16_truncate(v: i16x16) -> i8x16

converts i16 to i8, truncating the upper bits if they are set

pub fn blend(self, t: Self, f: Self) -> Self

pub fn is_positive(self) -> Self

Returns true for each positive element and false if it is zero or negative.

pub fn is_negative(self) -> Self

Returns true for each negative element and false if it is zero or positive.

pub fn reduce_add(self) -> i8

pub fn reduce_max(self) -> i8

pub fn reduce_min(self) -> i8

pub fn abs(self) -> Self

pub fn unsigned_abs(self) -> u8x16

pub fn signum(self) -> Self

Returns numbers representing the sign of each element.

  • 0 if the number is zero
  • 1 if the number is positive
  • -1 if the number is negative
pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

pub fn clamp(self, min: Self, max: Self) -> Self

Restrict each element to a certain interval.

If min > max, the result is unspeficied. Consider manually checking for that case.

pub fn from_slice_unaligned(input: &[i8]) -> Self

pub fn to_bitmask(self) -> u32

pub fn any(self) -> bool

pub fn all(self) -> bool

pub fn swizzle(self, rhs: i8x16) -> i8x16

Returns a new vector where each element is based on the index values in rhs.

  • Index values in the range [0, 15] select the i-th element of self.
  • Index values that are out of range will cause that output lane to be 0.
pub fn swizzle_relaxed(self, rhs: i8x16) -> i8x16

Works like swizzle with the following additional details

  • Indices in the range [0, 15] will select the i-th element of self.
  • If the high bit of any index is set (meaning that the index is negative), then the corresponding output lane is guaranteed to be zero.
  • Otherwise the output lane is either 0 or self[rhs[i] % 16], depending on the implementation.
pub fn none(self) -> bool

pub fn saturating_add(self, rhs: Self) -> Self

pub fn saturating_sub(self, rhs: Self) -> Self

pub fn saturating_mul(self, rhs: Self) -> Self

Lanewise saturating multiply.

pub fn saturating_div(self, rhs: Self) -> Self

Lanewise saturating divide.

Note that because division has no hardware support, this operation is very slow and should be avoided if possible.

pub fn transpose(data: [i8x16; 16]) -> [i8x16; 16]

Transpose matrix of 16x16 i8 matrix. Currently not accelerated.

pub fn to_array(self) -> [i8; 16]

pub fn as_array(&self) -> &[i8; 16]

pub fn as_mut_array(&mut self) -> &mut [i8; 16]

Source

impl i8x16

pub const fn splat(elem: i8) -> i8x16