pub struct u32x8 { /* private fields */ }Implementations
Sourceimpl u32x8
impl u32x8
pub const fn new(array: [u32; 8]) -> Self
Sourcepub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Outputwhere
Self: CmpEq<Rhs>,
pub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Outputwhere
Self: CmpEq<Rhs>,
Test if each element is equal to the corresponding element in other.
Sourcepub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Outputwhere
Self: CmpNe<Rhs>,
pub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Outputwhere
Self: CmpNe<Rhs>,
Test if each element is not equal to the corresponding element in
other.
Sourcepub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Outputwhere
Self: CmpLt<Rhs>,
pub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Outputwhere
Self: CmpLt<Rhs>,
Test if each element is less than the corresponding element in other.
Sourcepub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Outputwhere
Self: CmpGt<Rhs>,
pub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Outputwhere
Self: CmpGt<Rhs>,
Test if each element is greater than the corresponding element in
other.
Sourcepub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Outputwhere
Self: CmpLe<Rhs>,
pub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Outputwhere
Self: CmpLe<Rhs>,
Test if each element is less than or equal to the corresponding element
in other.
Sourcepub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Outputwhere
Self: CmpGe<Rhs>,
pub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Outputwhere
Self: CmpGe<Rhs>,
Test if each element is greater than or equal to the corresponding
element in other.
Sourcepub fn mul_keep_high(self, rhs: u32x8) -> u32x8
pub fn mul_keep_high(self, rhs: u32x8) -> u32x8
Multiplies 32x32 bit to 64 bit and then only keeps the high 32 bits of the
result. Useful for implementing divide constant value (see t_usefulness
example)
pub fn blend(self, t: Self, f: Self) -> Self
pub fn reduce_add(self) -> u32
pub fn reduce_max(self) -> u32
pub fn reduce_min(self) -> u32
pub fn max(self, rhs: Self) -> Self
pub fn min(self, rhs: Self) -> Self
Sourcepub fn clamp(self, min: Self, max: Self) -> Self
pub fn clamp(self, min: Self, max: Self) -> Self
Restrict each element to a certain interval.
If min > max, the result is unspeficied. Consider manually checking
for that case.
pub fn saturating_add(self, rhs: Self) -> Self
pub fn saturating_sub(self, rhs: Self) -> Self
Sourcepub fn saturating_mul(self, rhs: Self) -> Self
pub fn saturating_mul(self, rhs: Self) -> Self
Lanewise saturating multiply.
Sourcepub fn saturating_div(self, rhs: Self) -> Self
pub fn saturating_div(self, rhs: Self) -> Self
Lanewise saturating divide.
Note that because division has no hardware support, this operation is very slow and should be avoided if possible.
pub fn to_bitmask(self) -> u32
pub fn any(self) -> bool
pub fn all(self) -> bool
pub fn none(self) -> bool
Sourcepub fn transpose(data: [u32x8; 8]) -> [u32x8; 8]
pub fn transpose(data: [u32x8; 8]) -> [u32x8; 8]
Transpose matrix of 8x8 u32 matrix. Currently only accelerated on AVX2.
pub fn to_array(self) -> [u32; 8]
pub fn as_array(&self) -> &[u32; 8]
pub fn as_mut_array(&mut self) -> &mut [u32; 8]