u8x32

Struct u8x32 

pub struct u8x32 { /* private fields */ }

Implementations

Source

impl u8x32

pub const ONE: u8x32

pub const ZERO: u8x32

pub const MAX: u8x32

pub const MIN: u8x32

pub const LANES: u16 = 32

The number of lanes in this SIMD vector.

pub const BITS: u16 = 256

The size of this SIMD vector in bits.

Source

impl u8x32

pub const fn new(array: [u8; 32]) -> Self

pub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Output
where Self: CmpEq<Rhs>,

Test if each element is equal to the corresponding element in other.

pub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Output
where Self: CmpNe<Rhs>,

Test if each element is not equal to the corresponding element in other.

pub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Output
where Self: CmpLt<Rhs>,

Test if each element is less than the corresponding element in other.

pub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Output
where Self: CmpGt<Rhs>,

Test if each element is greater than the corresponding element in other.

pub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Output
where Self: CmpLe<Rhs>,

Test if each element is less than or equal to the corresponding element in other.

pub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Output
where Self: CmpGe<Rhs>,

Test if each element is greater than or equal to the corresponding element in other.

pub fn blend(self, t: Self, f: Self) -> Self

pub fn reduce_add(self) -> u8

pub fn reduce_max(self) -> u8

pub fn reduce_min(self) -> u8

pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

pub fn clamp(self, min: Self, max: Self) -> Self

Restrict each element to a certain interval.

If min > max, the result is unspeficied. Consider manually checking for that case.

pub fn saturating_add(self, rhs: Self) -> Self

pub fn saturating_sub(self, rhs: Self) -> Self

pub fn saturating_mul(self, rhs: Self) -> Self

Lanewise saturating multiply.

pub fn saturating_div(self, rhs: Self) -> Self

Lanewise saturating divide.

Note that because division has no hardware support, this operation is very slow and should be avoided if possible.

pub fn to_bitmask(self) -> u32

pub fn any(self) -> bool

pub fn all(self) -> bool

pub fn swizzle_half(self, rhs: i8x32) -> i8x32

Returns a new vector with lanes selected from the lanes of the first input vector a specified in the second input vector rhs. The indices i in range [0, 15] select the i-th element of self. For indices outside of the range the resulting lane is 0.

This note that is the equivalent of two parallel swizzle operations on the two halves of the vector, and the indexes each refer to the corresponding half.

pub fn swizzle_half_relaxed(self, rhs: u8x32) -> u8x32

Indices in the range [0, 15] will select the i-th element of self. If the high bit of any element of rhs is set (negative) then the corresponding output lane is guaranteed to be zero. Otherwise if the element of rhs is within the range [32, 127] then the output lane is either 0 or self[rhs[i] % 16] depending on the implementation.

This is the equivalent to two parallel swizzle operations on the two halves of the vector, and the indexes each refer to their corresponding half.

pub fn none(self) -> bool

pub fn transpose(data: [u8x32; 32]) -> [u8x32; 32]

Transpose matrix of 32x32 u8 matrix. Currently not accelerated.

pub fn to_array(self) -> [u8; 32]

pub fn as_array(&self) -> &[u8; 32]

pub fn as_mut_array(&mut self) -> &mut [u8; 32]

Source

impl u8x32

pub const fn splat(elem: u8) -> u8x32