pub struct i16x32 { /* private fields */ }Implementations
Sourceimpl i16x32
impl i16x32
pub const fn new(array: [i16; 32]) -> Self
pub fn simd_eq(self, rhs: Self) -> Self
pub fn simd_gt(self, rhs: Self) -> Self
pub fn simd_lt(self, rhs: Self) -> Self
pub fn blend(self, t: Self, f: Self) -> Self
Sourcepub fn reduce_add(self) -> i16
pub fn reduce_add(self) -> i16
horizontal add of all the elements of the vector
Sourcepub fn reduce_min(self) -> i16
pub fn reduce_min(self) -> i16
horizontal min of all the elements of the vector
Sourcepub fn reduce_max(self) -> i16
pub fn reduce_max(self) -> i16
horizontal max of all the elements of the vector
pub fn abs(self) -> Self
pub fn min(self, rhs: Self) -> Self
pub fn max(self, rhs: Self) -> Self
pub fn saturating_add(self, rhs: Self) -> Self
pub fn saturating_sub(self, rhs: Self) -> Self
Sourcepub fn dot(self, rhs: Self) -> i32x16
pub fn dot(self, rhs: Self) -> i32x16
Calculates partial dot product. Multiplies packed signed 16-bit integers, producing intermediate signed 32-bit integers. Horizontally add adjacent pairs of intermediate 32-bit integers.
pub fn to_bitmask(self) -> u32
pub fn to_array(self) -> [i16; 32]
pub fn as_array(&self) -> &[i16; 32]
pub fn as_mut_array(&mut self) -> &mut [i16; 32]