pub struct u8x32 { /* private fields */ }Implementations
Sourceimpl u8x32
impl u8x32
pub const fn new(array: [u8; 32]) -> Self
Sourcepub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Outputwhere
Self: CmpEq<Rhs>,
pub fn simd_eq<Rhs>(self, other: Rhs) -> <Self as CmpEq<Rhs>>::Outputwhere
Self: CmpEq<Rhs>,
Test if each element is equal to the corresponding element in other.
Sourcepub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Outputwhere
Self: CmpNe<Rhs>,
pub fn simd_ne<Rhs>(self, other: Rhs) -> <Self as CmpNe<Rhs>>::Outputwhere
Self: CmpNe<Rhs>,
Test if each element is not equal to the corresponding element in
other.
Sourcepub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Outputwhere
Self: CmpLt<Rhs>,
pub fn simd_lt<Rhs>(self, other: Rhs) -> <Self as CmpLt<Rhs>>::Outputwhere
Self: CmpLt<Rhs>,
Test if each element is less than the corresponding element in other.
Sourcepub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Outputwhere
Self: CmpGt<Rhs>,
pub fn simd_gt<Rhs>(self, other: Rhs) -> <Self as CmpGt<Rhs>>::Outputwhere
Self: CmpGt<Rhs>,
Test if each element is greater than the corresponding element in
other.
Sourcepub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Outputwhere
Self: CmpLe<Rhs>,
pub fn simd_le<Rhs>(self, other: Rhs) -> <Self as CmpLe<Rhs>>::Outputwhere
Self: CmpLe<Rhs>,
Test if each element is less than or equal to the corresponding element
in other.
Sourcepub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Outputwhere
Self: CmpGe<Rhs>,
pub fn simd_ge<Rhs>(self, other: Rhs) -> <Self as CmpGe<Rhs>>::Outputwhere
Self: CmpGe<Rhs>,
Test if each element is greater than or equal to the corresponding
element in other.
pub fn blend(self, t: Self, f: Self) -> Self
pub fn reduce_add(self) -> u8
pub fn reduce_max(self) -> u8
pub fn reduce_min(self) -> u8
pub fn max(self, rhs: Self) -> Self
pub fn min(self, rhs: Self) -> Self
Sourcepub fn clamp(self, min: Self, max: Self) -> Self
pub fn clamp(self, min: Self, max: Self) -> Self
Restrict each element to a certain interval.
If min > max, the result is unspeficied. Consider manually checking
for that case.
pub fn saturating_add(self, rhs: Self) -> Self
pub fn saturating_sub(self, rhs: Self) -> Self
Sourcepub fn saturating_mul(self, rhs: Self) -> Self
pub fn saturating_mul(self, rhs: Self) -> Self
Lanewise saturating multiply.
Sourcepub fn saturating_div(self, rhs: Self) -> Self
pub fn saturating_div(self, rhs: Self) -> Self
Lanewise saturating divide.
Note that because division has no hardware support, this operation is very slow and should be avoided if possible.
pub fn to_bitmask(self) -> u32
pub fn any(self) -> bool
pub fn all(self) -> bool
Sourcepub fn swizzle_half(self, rhs: i8x32) -> i8x32
pub fn swizzle_half(self, rhs: i8x32) -> i8x32
Returns a new vector with lanes selected from the lanes of the first input
vector a specified in the second input vector rhs.
The indices i in range [0, 15] select the i-th element of self. For
indices outside of the range the resulting lane is 0.
This note that is the equivalent of two parallel swizzle operations on the two halves of the vector, and the indexes each refer to the corresponding half.
Sourcepub fn swizzle_half_relaxed(self, rhs: u8x32) -> u8x32
pub fn swizzle_half_relaxed(self, rhs: u8x32) -> u8x32
Indices in the range [0, 15] will select the i-th element of self. If
the high bit of any element of rhs is set (negative) then the
corresponding output lane is guaranteed to be zero. Otherwise if the
element of rhs is within the range [32, 127] then the output lane is
either 0 or self[rhs[i] % 16] depending on the implementation.
This is the equivalent to two parallel swizzle operations on the two halves of the vector, and the indexes each refer to their corresponding half.
pub fn none(self) -> bool
Sourcepub fn transpose(data: [u8x32; 32]) -> [u8x32; 32]
pub fn transpose(data: [u8x32; 32]) -> [u8x32; 32]
Transpose matrix of 32x32 u8 matrix. Currently not accelerated.
pub fn to_array(self) -> [u8; 32]
pub fn as_array(&self) -> &[u8; 32]
pub fn as_mut_array(&mut self) -> &mut [u8; 32]